---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.
*NB:* for questions about pydeseq2 that are not related to a bug, please open a topic on the [scverse ecosystem Discourse forum](https://discourse.scverse.org/c/ecosystem/38).

**To Reproduce**
Provide snippets of code and steps on how to reproduce the behavior.
Please also specify the version you are using.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. iOS]
 - Version [e.g. 0.02]

**Additional context**
Add any other context about the problem here.
